@@ -4,4 +4,8 @@ pub mod mysql {
     pub struct MySqlRow;
 }
 
+pub mod postgres {
+    pub struct PgRow;
+}
+
 pub trait Row {}
